@@ -19,13 +19,13 @@
 namespace Breeze
 {
 //_________________________________________________________
-ConfigWidget::ConfigWidget(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
+ConfigWidget::ConfigWidget(QObject *parent, const KPluginMetaData &data, const QVariantList & /*args*/)
+    : KCModule(parent, data)
     , m_configuration(KSharedConfig::openConfig(QStringLiteral("breezerc")))
     , m_changed(false)
 {
     // configuration
-    m_ui.setupUi(this);
+    m_ui.setupUi(widget());
 
     // track ui changes
     connect(m_ui.titleAlignment, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()));
@@ -38,6 +38,7 @@ ConfigWidget::ConfigWidget(QWidget *parent, const QVariantList &args)
     connect(m_ui.shadowSize, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()));
     connect(m_ui.shadowStrength, SIGNAL(valueChanged(int)), SLOT(updateChanged()));
     connect(m_ui.shadowColor, &KColorButton::changed, this, &ConfigWidget::updateChanged);
+    connect(m_ui.outlineIntensity, SIGNAL(activated(int)), SLOT(updateChanged()));
 
     // track exception changes
     connect(m_ui.exceptions, &ExceptionListWidget::changed, this, &ConfigWidget::updateChanged);
@@ -70,11 +71,18 @@ void ConfigWidget::load()
     m_ui.shadowStrength->setValue(qRound(qreal(m_internalSettings->shadowStrength() * 100) / 255));
     m_ui.shadowColor->setColor(m_internalSettings->shadowColor());
 
+    // load outline intensity
+    if (m_internalSettings->outlineIntensity() <= InternalSettings::OutlineMaximum) {
+        m_ui.outlineIntensity->setCurrentIndex(m_internalSettings->outlineIntensity());
+    } else {
+        m_ui.outlineIntensity->setCurrentIndex(InternalSettings::OutlineMedium);
+    }
+
     // load exceptions
     ExceptionList exceptions;
     exceptions.readConfig(m_configuration);
     m_ui.exceptions->setExceptions(exceptions.get());
-    setChanged(false);
+    setNeedsSave(false);
 }
 
 //_________________________________________________________
@@ -94,6 +102,7 @@ void ConfigWidget::save()
     m_internalSettings->setShadowSize(m_ui.shadowSize->currentIndex());
     m_internalSettings->setShadowStrength(qRound(qreal(m_ui.shadowStrength->value() * 255) / 100));
     m_internalSettings->setShadowColor(m_ui.shadowColor->color());
+    m_internalSettings->setOutlineIntensity(m_ui.outlineIntensity->currentIndex());
 
     // save configuration
     m_internalSettings->save();
@@ -104,7 +113,7 @@ void ConfigWidget::save()
 
     // sync configuration
     m_configuration->sync();
-    setChanged(false);
+    setNeedsSave(false);
 
     // needed to tell kwin to reload when running from external kcmshell
     {
@@ -136,6 +145,7 @@ void ConfigWidget::defaults()
     m_ui.shadowSize->setCurrentIndex(m_internalSettings->shadowSize());
     m_ui.shadowStrength->setValue(qRound(qreal(m_internalSettings->shadowStrength() * 100) / 255));
     m_ui.shadowColor->setColor(m_internalSettings->shadowColor());
+    m_ui.outlineIntensity->setCurrentIndex(m_internalSettings->outlineIntensity());
 }
 
 //_______________________________________________
@@ -167,19 +177,15 @@ void ConfigWidget::updateChanged()
         modified = true;
     } else if (m_ui.shadowColor->color() != m_internalSettings->shadowColor()) {
         modified = true;
+    } else if (m_ui.outlineIntensity->currentIndex() != m_internalSettings->outlineIntensity()) {
+        modified = true;
 
         // exceptions
     } else if (m_ui.exceptions->isChanged()) {
         modified = true;
     }
 
-    setChanged(modified);
-}
-
-//_______________________________________________
-void ConfigWidget::setChanged(bool value)
-{
-    emit changed(value);
+    setNeedsSave(modified);
 }
 
 }
