@@ -264,7 +264,7 @@ QColor Helper::arrowColor(const QPalette &palette, bool mouseOver, bool hasFocus
 //____________________________________________________________________
 QColor Helper::sliderOutlineColor(const QPalette &palette, bool mouseOver, bool hasFocus, qreal opacity, AnimationMode mode) const
 {
-    QColor outline(KColorUtils::mix(palette.color(QPalette::Window), palette.color(QPalette::WindowText), 0.4));
+    QColor outline(KColorUtils::mix(palette.color(QPalette::Button), palette.color(QPalette::ButtonText), Metrics::Bias_Default));
 
     // hover takes precedence over focus
     if (mode == AnimationHover) {
@@ -372,7 +372,7 @@ QColor Helper::alphaColor(QColor color, qreal alpha) const
 }
 
 //______________________________________________________________________________
-void Helper::renderDebugFrame(QPainter *painter, const QRect &rect) const
+void Helper::renderDebugFrame(QPainter *painter, const QRectF &rect) const
 {
     painter->save();
     painter->setRenderHints(QPainter::Antialiasing);
@@ -383,7 +383,7 @@ void Helper::renderDebugFrame(QPainter *painter, const QRect &rect) const
 }
 
 //______________________________________________________________________________
-void Helper::renderFocusRect(QPainter *painter, const QRect &rect, const QColor &color, const QColor &outline, Sides sides) const
+void Helper::renderFocusRect(QPainter *painter, const QRectF &rect, const QColor &color, const QColor &outline, Sides sides) const
 {
     if (!color.isValid()) {
         return;
@@ -425,7 +425,7 @@ void Helper::renderFocusRect(QPainter *painter, const QRect &rect, const QColor
 }
 
 //______________________________________________________________________________
-void Helper::renderFocusLine(QPainter *painter, const QRect &rect, const QColor &color) const
+void Helper::renderFocusLine(QPainter *painter, const QRectF &rect, const QColor &color) const
 {
     if (!color.isValid()) {
         return;
@@ -442,7 +442,7 @@ void Helper::renderFocusLine(QPainter *painter, const QRect &rect, const QColor
 }
 
 //______________________________________________________________________________
-void Helper::renderFrameWithSides(QPainter *painter, const QRect &rect, const QColor &color, Qt::Edges edges, const QColor &outline) const
+void Helper::renderFrameWithSides(QPainter *painter, const QRectF &rect, const QColor &color, Qt::Edges edges, const QColor &outline) const
 {
     painter->save();
 
@@ -493,7 +493,7 @@ void Helper::renderFrameWithSides(QPainter *painter, const QRect &rect, const QC
 }
 
 //______________________________________________________________________________
-void Helper::renderFrame(QPainter *painter, const QRect &rect, const QColor &color, const QColor &outline) const
+void Helper::renderFrame(QPainter *painter, const QRectF &rect, const QColor &color, const QColor &outline) const
 {
     painter->setRenderHint(QPainter::Antialiasing);
 
@@ -522,7 +522,7 @@ void Helper::renderFrame(QPainter *painter, const QRect &rect, const QColor &col
 }
 
 //______________________________________________________________________________
-void Helper::renderSidePanelFrame(QPainter *painter, const QRect &rect, const QColor &outline, Side side) const
+void Helper::renderSidePanelFrame(QPainter *painter, const QRectF &rect, const QColor &outline, Side side) const
 {
     // check color
     if (!outline.isValid()) {
@@ -564,7 +564,8 @@ void Helper::renderSidePanelFrame(QPainter *painter, const QRect &rect, const QC
 }
 
 //______________________________________________________________________________
-void Helper::renderMenuFrame(QPainter *painter, const QRect &rect, const QColor &color, const QColor &outline, bool roundCorners, Qt::Edges seamlessEdges) const
+void Helper::renderMenuFrame(QPainter *painter, const QRectF &rect, const QColor &color, const QColor &outline, bool roundCorners, Qt::Edges seamlessEdges)
+    const
 {
     painter->save();
 
@@ -607,7 +608,7 @@ void Helper::renderMenuFrame(QPainter *painter, const QRect &rect, const QColor
 
     } else {
         painter->setRenderHint(QPainter::Antialiasing, false);
-        QRect frameRect(rect);
+        QRectF frameRect(rect);
 
         frameRect.adjust( //
             seamlessEdges.testFlag(Qt::LeftEdge) ? 1 : 0,
@@ -631,7 +632,7 @@ void Helper::renderMenuFrame(QPainter *painter, const QRect &rect, const QColor
 
 //______________________________________________________________________________
 void Helper::renderButtonFrame(QPainter *painter,
-                               const QRect &rect,
+                               const QRectF &rect,
                                const QPalette &palette,
                                const QHash<QByteArray, bool> &stateProperties,
                                qreal bgAnimation,
@@ -722,7 +723,7 @@ void Helper::renderButtonFrame(QPainter *painter,
 }
 
 //______________________________________________________________________________
-void Helper::renderToolBoxFrame(QPainter *painter, const QRect &rect, int tabWidth, const QColor &outline) const
+void Helper::renderToolBoxFrame(QPainter *painter, const QRectF &rect, int tabWidth, const QColor &outline) const
 {
     if (!outline.isValid()) {
         return;
@@ -734,7 +735,7 @@ void Helper::renderToolBoxFrame(QPainter *painter, const QRect &rect, int tabWid
 
     // if rect - tabwidth is even, need to increase tabWidth by 1 unit
     // for anti aliasing
-    if (!((rect.width() - tabWidth) % 2)) {
+    if (!((rect.toRect().width() - tabWidth) % 2)) {
         ++tabWidth;
     }
 
@@ -763,7 +764,7 @@ void Helper::renderToolBoxFrame(QPainter *painter, const QRect &rect, int tabWid
 }
 
 //______________________________________________________________________________
-void Helper::renderTabWidgetFrame(QPainter *painter, const QRect &rect, const QColor &color, const QColor &outline, Corners corners) const
+void Helper::renderTabWidgetFrame(QPainter *painter, const QRectF &rect, const QColor &color, const QColor &outline, Corners corners) const
 {
     painter->setRenderHint(QPainter::Antialiasing);
 
@@ -793,7 +794,7 @@ void Helper::renderTabWidgetFrame(QPainter *painter, const QRect &rect, const QC
 }
 
 //______________________________________________________________________________
-void Helper::renderSelection(QPainter *painter, const QRect &rect, const QColor &color) const
+void Helper::renderSelection(QPainter *painter, const QRectF &rect, const QColor &color) const
 {
     painter->setRenderHint(QPainter::Antialiasing);
     painter->setPen(Qt::NoPen);
@@ -802,7 +803,7 @@ void Helper::renderSelection(QPainter *painter, const QRect &rect, const QColor
 }
 
 //______________________________________________________________________________
-void Helper::renderSeparator(QPainter *painter, const QRect &rect, const QColor &color, bool vertical) const
+void Helper::renderSeparator(QPainter *painter, const QRectF &rect, const QColor &color, bool vertical) const
 {
     painter->setRenderHint(QPainter::Antialiasing, false);
     painter->setBrush(Qt::NoBrush);
@@ -820,7 +821,7 @@ void Helper::renderSeparator(QPainter *painter, const QRect &rect, const QColor
 
 //______________________________________________________________________________
 void Helper::renderCheckBoxBackground(QPainter *painter,
-                                      const QRect &rect,
+                                      const QRectF &rect,
                                       const QPalette &palette,
                                       CheckBoxState state,
                                       bool neutalHighlight,
@@ -844,7 +845,7 @@ void Helper::renderCheckBoxBackground(QPainter *painter,
     } else if (state == CheckOn || state == CheckPartial) {
         penBrush = palette.highlight().color();
     } else {
-        penBrush = transparentize(palette.text().color(), Metrics::Bias_Default);
+        penBrush = separatorColor(palette);
     }
     painter->setPen(QPen(penBrush, PenWidth::Frame));
 
@@ -874,7 +875,7 @@ void Helper::renderCheckBoxBackground(QPainter *painter,
 
 //______________________________________________________________________________
 void Helper::renderCheckBox(QPainter *painter,
-                            const QRect &rect,
+                            const QRectF &rect,
                             const QPalette &palette,
                             bool mouseOver,
                             CheckBoxState state,
@@ -961,13 +962,13 @@ void Helper::renderCheckBox(QPainter *painter,
             painter->drawPath(path);
             break;
         case CheckPartial:
-            if (animation >= 3 / 3) {
+            if (animation >= 3.0 / 3.0) {
                 painter->drawRect(rightDot);
             }
-            if (animation >= 2 / 3) {
+            if (animation >= 2.0 / 3.0) {
                 painter->drawRect(centerDot);
             }
-            if (animation >= 1 / 3) {
+            if (animation >= 1.0 / 3.0) {
                 painter->drawRect(leftDot);
             }
             break;
@@ -980,7 +981,7 @@ void Helper::renderCheckBox(QPainter *painter,
 
 //______________________________________________________________________________
 void Helper::renderRadioButtonBackground(QPainter *painter,
-                                         const QRect &rect,
+                                         const QRectF &rect,
                                          const QPalette &palette,
                                          RadioButtonState state,
                                          bool neutalHighlight,
@@ -1004,7 +1005,7 @@ void Helper::renderRadioButtonBackground(QPainter *painter,
     } else if (state == RadioOn) {
         penBrush = palette.highlight().color();
     } else {
-        penBrush = transparentize(palette.text().color(), Metrics::Bias_Default);
+        penBrush = separatorColor(palette);
     }
     painter->setPen(QPen(penBrush, PenWidth::Frame));
 
@@ -1029,7 +1030,7 @@ void Helper::renderRadioButtonBackground(QPainter *painter,
 
 //______________________________________________________________________________
 void Helper::renderRadioButton(QPainter *painter,
-                               const QRect &rect,
+                               const QRectF &rect,
                                const QPalette &palette,
                                bool mouseOver,
                                RadioButtonState state,
@@ -1086,7 +1087,7 @@ void Helper::renderRadioButton(QPainter *painter,
 }
 
 //______________________________________________________________________________
-void Helper::renderSliderGroove(QPainter *painter, const QRect &rect, const QColor &color) const
+void Helper::renderSliderGroove(QPainter *painter, const QRectF &rect, const QColor &fg, const QColor &bg) const
 {
     // setup painter
     painter->setRenderHint(QPainter::Antialiasing, true);
@@ -1096,17 +1097,16 @@ void Helper::renderSliderGroove(QPainter *painter, const QRect &rect, const QCol
     const qreal radius(0.5 * Metrics::Slider_GrooveThickness);
 
     // content
-    if (color.isValid()) {
-        painter->setPen(QPen(color, PenWidth::Frame));
-        auto bg = color;
-        bg.setAlphaF(bg.alphaF() / 2);
-        painter->setBrush(bg);
+    // content
+    if (fg.isValid()) {
+        painter->setPen(QPen(transparentize(fg, Metrics::Bias_Default), PenWidth::Frame));
+        painter->setBrush(KColorUtils::overlayColors(bg, alphaColor(fg, 0.7)));
         painter->drawRoundedRect(baseRect, radius, radius);
     }
 }
 
 //______________________________________________________________________________
-void Helper::renderDialGroove(QPainter *painter, const QRect &rect, const QColor &fg, const QColor &bg, qreal first, qreal last) const
+void Helper::renderDialGroove(QPainter *painter, const QRectF &rect, const QColor &fg, const QColor &bg, qreal first, qreal last) const
 {
     // setup painter
     painter->setRenderHint(QPainter::Antialiasing, true);
@@ -1121,9 +1121,8 @@ void Helper::renderDialGroove(QPainter *painter, const QRect &rect, const QColor
         // setup angles
         const int angleStart(first * 180 * 16 / M_PI);
         const int angleSpan((last - first) * 180 * 16 / M_PI);
-
         const QPen bgPen(fg, penWidth, Qt::SolidLine, Qt::RoundCap);
-        const QPen fgPen(KColorUtils::overlayColors(bg, alphaColor(fg, 0.5)), penWidth - 2, Qt::SolidLine, Qt::RoundCap);
+        const QPen fgPen(transparentize(KColorUtils::overlayColors(bg, alphaColor(fg, 0.5)), Metrics::Bias_Default), penWidth - 2, Qt::SolidLine, Qt::RoundCap);
 
         // setup pen
         if (angleSpan != 0) {
@@ -1162,7 +1161,7 @@ void Helper::initSliderStyleOption(const QSlider *slider, QStyleOptionSlider *op
 }
 
 //______________________________________________________________________________
-QRectF Helper::pathForSliderHandleFocusFrame(QPainterPath &focusFramePath, const QRect &rect, int hmargin, int vmargin) const
+QRectF Helper::pathForSliderHandleFocusFrame(QPainterPath &focusFramePath, const QRectF &rect, int hmargin, int vmargin) const
 {
     // Mimics path and adjustments of renderSliderHandle
     QRectF frameRect(rect);
@@ -1176,7 +1175,7 @@ QRectF Helper::pathForSliderHandleFocusFrame(QPainterPath &focusFramePath, const
 }
 
 //______________________________________________________________________________
-void Helper::renderSliderHandle(QPainter *painter, const QRect &rect, const QColor &color, const QColor &outline, const QColor &shadow, bool sunken) const
+void Helper::renderSliderHandle(QPainter *painter, const QRectF &rect, const QColor &color, const QColor &outline, const QColor &shadow, bool sunken) const
 {
     // setup painter
     painter->setRenderHint(QPainter::Antialiasing, true);
@@ -1211,7 +1210,7 @@ void Helper::renderSliderHandle(QPainter *painter, const QRect &rect, const QCol
 }
 
 //______________________________________________________________________________
-void Helper::renderProgressBarGroove(QPainter *painter, const QRect &rect, const QColor &fg, const QColor &bg) const
+void Helper::renderProgressBarGroove(QPainter *painter, const QRectF &rect, const QColor &fg, const QColor &bg) const
 {
     // setup painter
     painter->setRenderHint(QPainter::Antialiasing, true);
@@ -1222,15 +1221,15 @@ void Helper::renderProgressBarGroove(QPainter *painter, const QRect &rect, const
 
     // content
     if (fg.isValid()) {
-        painter->setPen(QPen(fg, PenWidth::Frame));
-        painter->setBrush(KColorUtils::overlayColors(bg, alphaColor(fg, 0.5)));
+        painter->setPen(QPen(transparentize(fg, Metrics::Bias_Default), PenWidth::Frame));
+        painter->setBrush(KColorUtils::overlayColors(bg, alphaColor(fg, 0.7)));
         painter->drawRoundedRect(baseRect, radius, radius);
     }
 }
 
 //______________________________________________________________________________
 void Helper::renderProgressBarBusyContents(QPainter *painter,
-                                           const QRect &rect,
+                                           const QRectF &rect,
                                            const QColor &first,
                                            const QColor &second,
                                            bool horizontal,
@@ -1281,7 +1280,7 @@ void Helper::renderProgressBarBusyContents(QPainter *painter,
 }
 
 //______________________________________________________________________________
-void Helper::renderScrollBarHandle(QPainter *painter, const QRect &rect, const QColor &fg, const QColor &bg) const
+void Helper::renderScrollBarHandle(QPainter *painter, const QRectF &rect, const QColor &fg, const QColor &bg) const
 {
     // setup painter
     painter->setRenderHint(QPainter::Antialiasing, true);
@@ -1290,7 +1289,7 @@ void Helper::renderScrollBarHandle(QPainter *painter, const QRect &rect, const Q
     const qreal radius(0.5 * std::min({baseRect.width(), baseRect.height(), (qreal)Metrics::ScrollBar_SliderWidth}));
 
     painter->setPen(Qt::NoPen);
-    painter->setPen(QPen(fg, 1.001));
+    painter->setPen(QPen(transparentize(fg, Metrics::Bias_Default), 1.001));
     painter->setBrush(KColorUtils::overlayColors(bg, alphaColor(fg, 0.5)));
     painter->drawRoundedRect(strokedRect(baseRect), radius, radius);
 }
@@ -1320,7 +1319,7 @@ void Helper::renderScrollBarGroove(QPainter *painter, const QRect &rect, const Q
 }
 
 //______________________________________________________________________________
-void Helper::renderScrollBarBorder(QPainter *painter, const QRect &rect, const QColor &color) const
+void Helper::renderScrollBarBorder(QPainter *painter, const QRectF &rect, const QColor &color) const
 {
     // content
     if (color.isValid()) {
@@ -1332,7 +1331,7 @@ void Helper::renderScrollBarBorder(QPainter *painter, const QRect &rect, const Q
 
 //______________________________________________________________________________
 void Helper::renderTabBarTab(QPainter *painter,
-                             const QRect &rect,
+                             const QRectF &rect,
                              const QPalette &palette,
                              const QHash<QByteArray, bool> &stateProperties,
                              Corners corners,
@@ -1356,19 +1355,12 @@ void Helper::renderTabBarTab(QPainter *painter,
     QColor bgBrush;
 
     if (selected) {
-        if (north) {
-            // overlap bottom border
-            frameRect.adjust(0, 0, 0, 1);
-        } else if (south) {
-            // overlap top border
-            frameRect.adjust(0, -1, 0, 0);
-        } else if (west) {
-            // overlap right border
-            frameRect.adjust(0, 0, 1, 0);
-        } else if (east) {
-            // overlap left border
-            frameRect.adjust(-1, 0, 0, 0);
-        }
+        // overlap border
+        // This covers just enough of the border, so that both the border and it's
+        // antialiasing effect is covered. On 100% scale it does nothing
+        const qreal overlap = devicePixelRatio(painter) * devicePixelRatio(painter);
+        frameRect.adjust(east ? -overlap : 0, south ? -overlap : 0, west ? overlap : 0, north ? overlap : 0);
+
         if (documentMode && !isQtQuickControl && !hasAlteredBackground) {
             bgBrush = palette.color(QPalette::Window);
         } else {
@@ -1395,19 +1387,12 @@ void Helper::renderTabBarTab(QPainter *painter,
         painter->setPen(Qt::NoPen);
         painter->drawPath(highlightPath);
     } else {
-        if (north) {
-            // don't overlap bottom border
-            frameRect.adjust(0, 0, 0, -1);
-        } else if (south) {
-            // don't overlap top border
-            frameRect.adjust(0, 1, 0, 0);
-        } else if (west) {
-            // don't overlap right border
-            frameRect.adjust(0, 0, -1, 0);
-        } else if (east) {
-            // don't overlap left border
-            frameRect.adjust(1, 0, 0, 0);
-        }
+        // don't overlap border
+        // Since we dont set the rectangle as strokedRect here, modify only one side of it
+        // the same amount strokedRect method would, to make it snap next to the border
+        const qreal overlap = PenWidth::Frame;
+        frameRect.adjust(east ? overlap : 0, south ? overlap : 0, west ? -overlap : 0, north ? -overlap : 0);
+
         const auto windowColor = palette.color(QPalette::Window);
         bgBrush = windowColor.darker(120);
         const auto hover = alphaColor(hoverColor(palette), 0.2);
@@ -1424,9 +1409,9 @@ void Helper::renderTabBarTab(QPainter *painter,
 }
 
 //______________________________________________________________________________
-void Helper::renderArrow(QPainter *painter, const QRect &rect, const QColor &color, ArrowOrientation orientation) const
+void Helper::renderArrow(QPainter *painter, const QRectF &rect, const QColor &color, ArrowOrientation orientation) const
 {
-    int size = std::min({rect.width(), rect.height(), Metrics::ArrowSize});
+    int size = std::min({rect.toRect().width(), rect.toRect().height(), Metrics::ArrowSize});
     // No point in trying to draw if it's too small
     if (size <= 0) {
         return;
@@ -1494,10 +1479,10 @@ void Helper::renderArrow(QPainter *painter, const QRect &rect, const QColor &col
 }
 
 //______________________________________________________________________________
-void Helper::renderDecorationButton(QPainter *painter, const QRect &rect, const QColor &color, ButtonType buttonType, bool inverted) const
+void Helper::renderDecorationButton(QPainter *painter, const QRectF &rect, const QColor &color, ButtonType buttonType, bool inverted) const
 {
     painter->save();
-    painter->setViewport(rect);
+    painter->setViewport(rect.toRect());
     painter->setWindow(0, 0, 18, 18);
     painter->setRenderHints(QPainter::Antialiasing);
 
@@ -1787,4 +1772,9 @@ Qt::Edges Helper::menuSeamlessEdges(const QWidget *widget)
     }
     return Qt::Edges();
 }
+
+qreal Helper::devicePixelRatio(QPainter *painter) const
+{
+    return painter->device() ? painter->device()->devicePixelRatioF() : qApp->devicePixelRatio();
+}
 }
